@@ -17,6 +17,7 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ###########################################################################
 import os
+import subprocess
 import sys
 import time
 import shutil
@@ -172,6 +173,9 @@ class linux_intelligent_ocr_solution():
 		self.scanner_objects = []
 		self.is_updating_scanner_list = False
 
+		# Initialize locking mechanism
+		loop.threads_init()
+
 		#Load Preferences
 		self.preferences = preferences.lios_preferences()
 		self.preferences.set_from_file(macros.preferences_file_path)
@@ -488,11 +492,40 @@ class linux_intelligent_ocr_solution():
 		destination = "{0}{1}".format(macros.tmp_dir,pdf_filename)		
 		shutil.copyfile(pdf_filename_full,destination)
 		os.makedirs(destination.split(".")[0],exist_ok=True)
-		
+
+		out = subprocess.getoutput("pdffonts {}".format(destination))
+		pdf_type = "Text"
+		if (len(out) < 300):
+			pdf_type = "Image"
+
+		dlg_set_tool = dialog.Dialog(_("Select PDF Type"),
+		(_("Containing images only"), dialog.Dialog.BUTTON_ID_2,
+		_("Containing text or images"), dialog.Dialog.BUTTON_ID_1))
+
+
+		label = widget.Label(_(
+		"Please select PDF Type. Seems to me that {} is a {} PDF."
+		.format(pdf_filename, pdf_type)))
+
+		dlg_set_tool.add_widget(label)
+		label.show()
+
+		# Sleep 1 second for avoiding freeze while opening with pdf file
+		time.sleep(1)
+
+		loop.acquire_lock()
+		response = dlg_set_tool.run()
+		if(response == dialog.Dialog.BUTTON_ID_1):
+			conversion_tool = "pdftoppm"
+		else:
+			conversion_tool = "pdfimages"
+		dlg_set_tool.destroy()
+		loop.release_lock()
+
 		self.notify_information(_("Extracting images from Pdf"))
-		
-		p = multiprocessing.Process(target=lambda : os.system("pdfimages {} {}/{}"
-		.format(destination,destination.split(".")[0],pdf_filename.split(".")[0])) , args=())
+
+		p = multiprocessing.Process(target=lambda : os.system("{} {} {}/{} -png"
+		.format(conversion_tool, destination,destination.split(".")[0],pdf_filename.split(".")[0])) , args=())
 		
 		p.start()
 		while(p.is_alive()):
@@ -694,8 +727,8 @@ class linux_intelligent_ocr_solution():
 			self.notify_information(_("No Scanner Detected!. Please update scanner list and try again"),0)
 			return;
 
-		self.notify_information(_("Scanning {} with resolution={} brightness={}").
-		format(filename,self.preferences.scan_resolution,self.preferences.scan_brightness))
+		self.notify_information(_("Scanning {}, resolution {}, brightness {}").
+		format(filename.split("/")[-1],self.preferences.scan_resolution,self.preferences.scan_brightness))
 		
 		p = multiprocessing.Process(target=(self.scanner_objects[selected_scanner].scan),
 		args=(filename,self.preferences.scan_resolution,
@@ -879,7 +912,7 @@ class linux_intelligent_ocr_solution():
 		self.process_breaker = False
 		mode = self.preferences.mode_of_rotation
 		if (mode == 0 or mode == 1):
-			self.notify_information(_("Scanning with resolution={} brightness={} for detecting angle of rotation")
+			self.notify_information(_("Scanning with resolution {}, brightness {}, for detecting angle of rotation.")
 			.format(self.preferences.scan_resolution,self.preferences.scan_brightness))
 			
 			p = multiprocessing.Process(target=(self.scanner_objects[selected_scanner].scan),
@@ -1010,10 +1043,10 @@ class linux_intelligent_ocr_solution():
 				#self.announce(_("Got {} words at brightness {}.").format(previous_optimised_count,mid_value))
 			else:
 				if (count != -1):
-					self.notify_information(_("Got {} words at brightness {}. Scanning with resolution={} brightness={}")
+					self.notify_information(_("Got {} words at brightness {}. Scanning with resolution {}, brightness {}.")
 					.format(count,pos-distance,self.preferences.scan_resolution,pos))
 				else:
-					self.notify_information(_("Scanning with resolution={} brightness={}")
+					self.notify_information(_("Scanning with resolution {}, brightness {}.")
 					.format(self.preferences.scan_resolution,pos))
 				
 				p = multiprocessing.Process(target=(self.scanner_objects[selected_scanner].scan),
@@ -1402,6 +1435,9 @@ pacman -S aspell-fr""").format(languages[self.preferences.language]))
 
 			if item.split('.')[-1] in ["pdf","Pdf"]:
 				self.import_images_from_pdf(item)
+				# import_images_from_pdf is a threaded function
+				# so stoping with one file
+				break;
 
 			if item.split('.')[-1] in macros.supported_text_formats:
 				text = editor.read_text_from_file(item)
